package Video::Delay;

# Pragmas.
use strict;
use warnings;

# Version.
our $VERSION = 0.05;

1;

__END__

=pod

=encoding utf8

=head1 NAME

 Video::Delay - Perl classes for delays between frames generation.

=head1 SEE ALSO

=over

=item L<Video::Delay::Array>

Video::Delay class for predefined list of delays.

=item L<Video::Delay::Const>

Video::Delay class for constant delay.

=item L<Video::Delay::Func>

Video::Delay class for delays defined by math function.

=back

=head1 REPOSITORY

L<https://github.com/tupinek/Video-Delay>

=head1 AUTHOR

Michal Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

 © 2012-2015 Michal Špaček
 BSD 2-Clause License

=head1 VERSION 

0.02

=cut
